"""Top-level package for Sumeh DQ."""

__author__ = """Demetrius Albuquerque"""
__email__ = "demetrius.albuquerque@yahoo.com.br"
__version__ = "0.1.0"

from .core import report
from .services.config import *
from .engine import *
